/**
 * legoino-device-information - Device information for all our arduino derived projects
 * @version v1.2.1
 * @link https://github.com/Hackuarium/legoino-device-information#readme
 * @license MIT
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.legoinoDeviceInformation = factory());
}(this, (function () { 'use strict';

  var OpenBio = {
    name: 'Open bioreactor',
    kind: 'OpenBio',
    description: '',
    url: '',
    id: '$',
    numberParameters: 52,
    numberLogParameters: 26,
    parameters: [{
      label: 'A',
      variable: 'liquidTemp',
      name: 'T° LIQ',
      description: 'Temperature of the bioreactor solution',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'B',
      variable: 'pcbTemp',
      name: 'T° PCB',
      description: 'Temperature of the bioreactor circuit',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'C',
      variable: 'pidTemp',
      name: 'Pid',
      description: 'PID absolute value',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'D',
      variable: 'targetTemp',
      name: 'T° target',
      description: 'Target temperature',
      factor: 100,
      unit: '°C',
      writable: true
    }, {
      label: 'E',
      variable: 'weight',
      name: 'Weight',
      description: 'Weight of the bioreactor tank, in internal value',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'F',
      variable: 'grWeight',
      name: 'Weight (g)',
      description: 'Weight of the bioreactor tank, in gr if calibrated',
      factor: 1,
      unit: 'g',
      writable: false
    }, {
      label: 'G',
      variable: 'waitSinceLast',
      name: 'Time since last event',
      description: 'Time in min since last weight event',
      factor: 1,
      unit: 'min',
      writable: false
    }, {
      label: 'H',
      variable: 'minWeight',
      name: 'Weight min',
      description: 'Weight min in internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'I',
      variable: 'maxWeight',
      name: 'Weight max',
      description: 'Weight max in internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'J'
    }, {
      label: 'K'
    }, {
      label: 'L'
    }, {
      label: 'M'
    }, {
      label: 'N'
    }, {
      label: 'O'
    }, {
      label: 'P'
    }, {
      label: 'Q'
    }, {
      label: 'R'
    }, {
      label: 'S'
    }, {
      label: 'T'
    }, {
      label: 'U'
    }, {
      label: 'V'
    }, {
      label: 'W'
    }, {
      label: 'X'
    }, {
      label: 'Y',
      variable: 'error',
      name: 'Error',
      unit: '',
      factor: 1,
      description: `
            bit 0: pcb probe, 1: liquid probe, 2: pcb temperature,
            3: liquid temperature, 4: target temp. range, 5: weight range`,
      writable: true,
      flags: {
        pcbProbe: {
          bit: 0,
          description: 'PCB temperature probe not responding'
        },
        liquidProbe: {
          bit: 1,
          description: 'Liquid temperature probe not responding'
        },
        pcbTemperature: {
          bit: 2,
          description: 'PCB temperature out of range'
        },
        liquidTemperature: {
          bit: 3,
          description: 'Liquid temperature out of range'
        },
        targetTemperature: {
          bit: 4,
          description: 'Target temperature out of range'
        },
        weight: {
          bit: 5,
          description: 'Weight out of range'
        }
      }
    }, {
      label: 'Z',
      variable: 'status',
      name: 'Status',
      description: `Status of the Bioreactor, the bits of this integer code
        for the state of specific elements of the reactor (eg. motor ON/OFF, PUMP ON/OFF etc.).
        bits: 0: stepper, 1: weight, 2: pid, 7: sedimentation, 8: filling, 9: emptying
        `,
      factor: 1,
      unit: '',
      writable: true,
      flags: {
        stepper: {
          bit: 0,
          description: 'Stepper running'
        },
        food: {
          bit: 1,
          description: 'Food running'
        },
        pid: {
          bit: 2,
          description: 'PID running'
        },
        sedimentation: {
          bit: 7,
          description: 'Sedimentation running'
        },
        filling: {
          bit: 8,
          description: 'Filling tank'
        },
        emptying: {
          bit: 9,
          description: 'Emptying tank'
        }
      }
    }, {
      label: 'AA',
      variable: 'stepperSpeed',
      name: 'Stepper speed',
      description: '',
      factor: 1,
      unit: 'RPM',
      writable: true
    }, {
      label: 'AB',
      variable: 'stepperOnDelay',
      name: 'Stepper on delay',
      description: 'Time in (s) for which the stepper stays on',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'AC',
      variable: 'stepperOffDelay',
      name: 'Stepper off delay',
      description: 'Time to wait in (s) before between stirring periods',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'AD'
    }, {
      label: 'AE'
    }, {
      label: 'AF',
      variable: 'sedTime',
      name: 'Sedimentation Time',
      description: 'Sedimentation time in min after Semi-batch operation,' + 'corresponds to the waiting time without stirring before emptying the reactor to the minimum level',
      min: 0,
      max: 32767,
      factor: 1,
      unit: 'min',
      writable: true
    }, {
      label: 'AG',
      variable: 'filledTime',
      name: 'Filled Time',
      description: 'Filled time in min after Semi-batch operation,' + 'corresponds to the total time with and without stirring before emptying the reactor to the minimum level' + 'must be set longer than the sedimentation time if stirring is desired',
      min: 0,
      max: 32767,
      factor: 1,
      unit: 'min',
      writable: true
    }, {
      label: 'AH',
      variable: 'weightFactor',
      name: 'Weight factor',
      description: 'Factor allowing to convert the internal weight value to g',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AI',
      variable: 'weightOffset',
      name: 'Weight offset',
      description: '',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AJ'
    }, {
      label: 'AK'
    }, {
      label: 'AL'
    }, {
      label: 'AM'
    }, {
      label: 'AN'
    }, {
      label: 'AO'
    }, {
      label: 'AP'
    }, {
      label: 'AQ'
    }, {
      label: 'AR'
    }, {
      label: 'AS'
    }, {
      label: 'AT'
    }, {
      label: 'AU'
    }, {
      label: 'AV'
    }, {
      label: 'AW'
    }, {
      label: 'AX'
    }, {
      label: 'AY'
    }, {
      label: 'AZ',
      variable: 'enable',
      name: 'Enable',
      description: 'pid - food - stepper : ex. 1: only stepper',
      factor: 1,
      unit: '',
      writable: true,
      flags: {
        stepper: {
          bit: 0,
          description: 'Stepper control'
        },
        food: {
          bit: 1,
          description: 'Food control'
        },
        pid: {
          bit: 2,
          description: 'PID control'
        }
      }
    }],
    events: [{
      id: 1,
      name: 'Arduino boot',
      description: ''
    }, {
      id: 2,
      name: 'Set safe mode',
      description: ''
    }, {
      id: 3,
      name: 'Status enable',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'stepper',
        1: 'food',
        2: 'pid',
        7: 'sedimentation',
        8: 'filling',
        9: 'emptying'
      }
    }, {
      id: 4,
      name: 'Status disable',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'stepper',
        1: 'food',
        2: 'pid',
        7: 'sedimentation',
        8: 'filling',
        9: 'emptying'
      }
    }, {
      id: 6,
      name: 'Error: failed',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'pcb temperature probe',
        1: 'liquid temperature probe',
        2: 'pcb temperature range',
        3: 'liquid temperature range',
        4: 'target temperature range',
        5: 'weight range'
      }
    }, {
      id: 7,
      name: 'Error: recover',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'pcb temperature probe',
        1: 'liquid temperature probe',
        2: 'pcb temperature range',
        3: 'liquid temperature range',
        4: 'target temperature range',
        5: 'weight range'
      }
    }, {
      id: 20,
      name: 'Rotation start',
      description: ''
    }, {
      id: 21,
      name: 'Rotation stop',
      description: ''
    }, {
      id: 150,
      name: 'Not found log entry N',
      description: ''
    }, {
      id: 255,
      name: 'Save all parameters',
      description: ''
    }, {
      id: 256,
      name: 'Change value of A',
      description: ''
    }, {
      id: 257,
      name: 'Change value of B',
      description: ''
    }]
  };

  var OpenBio6 = {
    name: 'Open bioreactor v6',
    kind: 'OpenBio6',
    description: '',
    url: '',
    id: '6',
    numberParameters: 68,
    numberLogParameters: 26,
    parameters: [{
      label: 'A',
      variable: 'externalTemperature1',
      name: 'T° EXT 1',
      description: 'External temperature 1',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'B',
      variable: 'externalTemperature2',
      name: 'T° EXT 2',
      description: 'External temperature 2',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'C',
      variable: 'pcbTemp',
      name: 'T° PCB',
      description: 'Temperature of the bioreactor circuit',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'D',
      variable: 'pidTemp',
      name: 'Pid',
      description: 'PID absolute value',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'E',
      variable: 'targetTemp',
      name: 'T° target',
      description: 'Target temperature',
      factor: 100,
      unit: '°C',
      writable: true
    }, {
      label: 'F',
      variable: 'weight',
      name: 'Weight',
      description: 'Weight of the bioreactor tank, in internal value',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'G',
      variable: 'grWeight',
      name: 'Weight (g)',
      description: 'Weight of the bioreactor tank, in gr if calibrated',
      factor: 1,
      unit: 'g',
      writable: false
    }, {
      label: 'H',
      variable: 'minWeight',
      name: 'Weight min',
      description: 'Weight min in internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'I',
      variable: 'maxWeight',
      name: 'Weight max',
      description: 'Weight max in internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'J'
    }, {
      label: 'K'
    }, {
      label: 'L'
    }, {
      label: 'M'
    }, {
      label: 'N'
    }, {
      label: 'O'
    }, {
      label: 'P'
    }, {
      label: 'Q'
    }, {
      label: 'R'
    }, {
      label: 'S'
    }, {
      label: 'T'
    }, {
      label: 'U'
    }, {
      label: 'V'
    }, {
      label: 'W',
      variable: 'currentStep',
      name: 'Current step',
      description: 'Current step in the pipeline',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'X',
      variable: 'currentWaitTime',
      name: 'Current wait time',
      description: 'Current step wait time',
      factor: 1,
      unit: 'min',
      writable: false
    }, {
      label: 'Y',
      variable: 'error',
      name: 'Error',
      unit: '',
      factor: 1,
      description: `
            bit 0: pcb probe, 1: liquid probe, 2: pcb temperature,
            3: liquid temperature, 4: target temp. range, 5: weight range`,
      writable: true,
      flags: {
        0: 'PCB temperature probe error',
        1: 'External temperature 1 probe error',
        2: 'External temperature 2 probe error',
        3: 'PCB temperature out of range',
        4: 'External temperature 1 out of range',
        5: 'External temperature 2 out of range',
        6: 'Target temperature out of range',
        7: 'Weight out of range'
      }
    }, {
      label: 'Z',
      variable: 'status',
      name: 'Status',
      description: `Status of the Bioreactor, the bits of this integer code
        for the state of specific elements of the reactor (eg. motor ON/OFF, PUMP ON/OFF etc.).
        bits: 0: stepper, 1: weight, 2: pid, 7: sedimentation, 8: filling, 9: emptying
        `,
      factor: 1,
      unit: '',
      writable: true,
      flags: {
        0: 'pid',
        1: 'stepper',
        2: 'output 1',
        3: 'output 2',
        4: 'output 3',
        5: 'output 4'
      }
    }, {
      label: 'AA',
      variable: 'stepperSpeed',
      name: 'Stepper speed',
      description: '',
      factor: 1,
      unit: 'RPM',
      writable: true
    }, {
      label: 'AB',
      variable: 'stepperSteps',
      name: 'Stepper steps',
      description: 'Number of step before changing direction. 1 tour = 200 steps',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'AC',
      variable: 'stepperOffDelay',
      name: 'Stepper off delay',
      description: 'Time to wait in (s) before between stirring periods',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'AD',
      variable: 'weightFactor',
      name: 'Weight factor',
      description: 'Factor allowing to convert the internal weight value to g',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AE',
      variable: 'weightOffset',
      name: 'Weight offset',
      description: '',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AF'
    }, {
      label: 'AG'
    }, {
      label: 'AH'
    }, {
      label: 'AI'
    }, {
      label: 'AJ'
    }, {
      label: 'AK'
    }, {
      label: 'AL'
    }, {
      label: 'AM'
    }, {
      label: 'AN'
    }, {
      label: 'AO'
    }, {
      label: 'AP'
    }, {
      label: 'AQ'
    }, {
      label: 'AR'
    }, {
      label: 'AS'
    }, {
      label: 'AT'
    }, {
      label: 'AU'
    }, {
      label: 'AV'
    }, {
      label: 'AW'
    }, {
      label: 'AX'
    }, {
      label: 'AY'
    }, {
      label: 'AZ',
      variable: 'enable',
      name: 'Enable',
      description: 'pid - food - stepper : ex. 1: only stepper',
      factor: 1,
      unit: '',
      writable: true,
      flags: {
        0: 'pid',
        1: 'stepper',
        2: 'output 1',
        3: 'output 2',
        4: 'output 3',
        5: 'output 4'
      }
    }, {
      label: 'BA',
      variable: 'step01',
      name: 'Step 1',
      description: 'Step 1'
    }, {
      label: 'BB',
      variable: 'step02',
      name: 'Step 2',
      description: 'Step 2'
    }, {
      label: 'BC',
      variable: 'step03',
      name: 'Step 3',
      description: 'Step 3'
    }, {
      label: 'BD',
      variable: 'step04',
      name: 'Step 4',
      description: 'Step 4'
    }, {
      label: 'BE',
      variable: 'step05',
      name: 'Step 5',
      description: 'Step 5'
    }, {
      label: 'BF',
      variable: 'step06',
      name: 'Step 6',
      description: 'Step 6'
    }, {
      label: 'BG',
      variable: 'step07',
      name: 'Step 7',
      description: 'Step 7'
    }, {
      label: 'Bh',
      variable: 'step08',
      name: 'Step 8',
      description: 'Step 8'
    }, {
      label: 'BI',
      variable: 'step09',
      name: 'Step 9',
      description: 'Step 9'
    }, {
      label: 'BJ',
      variable: 'step10',
      name: 'Step 10',
      description: 'Step 10'
    }, {
      label: 'BK',
      variable: 'step11',
      name: 'Step 11',
      description: 'Step 11'
    }, {
      label: 'BL',
      variable: 'step12',
      name: 'Step 12',
      description: 'Step 12'
    }, {
      label: 'BM',
      variable: 'step13',
      name: 'Step 13',
      description: 'Step 13'
    }, {
      label: 'BN',
      variable: 'step14',
      name: 'Step 14',
      description: 'Step 14'
    }, {
      label: 'BO',
      variable: 'step15',
      name: 'Step 15',
      description: 'Step 15'
    }, {
      label: 'BP',
      variable: 'step16',
      name: 'Step 16',
      description: 'Step 16'
    }],
    events: [{
      id: 1,
      name: 'Arduino boot',
      description: ''
    }, {
      id: 2,
      name: 'Set safe mode',
      description: ''
    }, {
      id: 3,
      name: 'Status enable',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'stepper',
        1: 'food',
        2: 'pid',
        7: 'sedimentation',
        8: 'filling',
        9: 'emptying'
      }
    }, {
      id: 4,
      name: 'Status disable',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'stepper',
        1: 'food',
        2: 'pid',
        7: 'sedimentation',
        8: 'filling',
        9: 'emptying'
      }
    }, {
      id: 6,
      name: 'Error: failed',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'pcb temperature probe',
        1: 'liquid temperature probe',
        2: 'pcb temperature range',
        3: 'liquid temperature range',
        4: 'target temperature range',
        5: 'weight range'
      }
    }, {
      id: 7,
      name: 'Error: recover',
      description: '0:stepper, 1:food, 2:pid, 7:sedimentation, 8:filling, 9:emptying',
      flags: {
        0: 'pcb temperature probe',
        1: 'liquid temperature probe',
        2: 'pcb temperature range',
        3: 'liquid temperature range',
        4: 'target temperature range',
        5: 'weight range'
      }
    }, {
      id: 20,
      name: 'Rotation start',
      description: ''
    }, {
      id: 21,
      name: 'Rotation stop',
      description: ''
    }, {
      id: 150,
      name: 'Not found log entry N',
      description: ''
    }, {
      id: 255,
      name: 'Save all parameters',
      description: ''
    }, {
      id: 256,
      name: 'Change value of A',
      description: ''
    }, {
      id: 257,
      name: 'Change value of B',
      description: ''
    }]
  };

  var OpenSpectro = {
    name: 'Open spectrophotometer',
    kind: 'OpenSpectro',
    numberParameters: 26,
    id: 'S',
    description: '',
    url: '',
    parameters: [{
      label: 'A',
      name: 'Red point',
      description: 'which point of the linear detector is the maximum for red',
      factor: 1,
      unit: 'pixel#',
      writable: false
    }, {
      label: 'B',
      name: 'Green point',
      description: 'which point of the linear detector is the maximum for green',
      factor: 1,
      unit: 'pixel#',
      writable: false
    }, {
      label: 'C',
      name: 'Blue point',
      description: 'which point of the linear detector is the maximum for blue',
      factor: 1,
      unit: 'pixel#',
      writable: false
    }, {
      label: 'D',
      name: 'Compression',
      description: '0 means no compression, can be set',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'E',
      name: 'R-Intensity',
      description: 'Red led intensity (0 to 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'F',
      name: 'G-Intensity',
      description: 'Green led intensity (0 to 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'G',
      name: 'B-Intensity',
      description: 'Blue led intensity (0 to 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'H',
      name: 'Scan#',
      description: 'Number of scans (maximum 64)',
      factor: 1,
      unit: '',
      min: 1,
      max: 64,
      writable: true
    }, {
      label: 'I',
      name: 'DelayExp',
      description: 'Delay between experiments in seconds',
      factor: 1,
      unit: 's',
      writable: false
    }, {
      label: 'J',
      name: 'Acq Time',
      description: 'Accumulation time in ms(in ms, good value=30)',
      factor: 1,
      unit: 'ms',
      writable: true
    }, {
      label: 'K',
      name: 'lambda-R',
      description: 'Red maximum wavelength (nm)',
      factor: 1,
      unit: 'nm',
      writable: false
    }, {
      label: 'L',
      name: 'lambda-G',
      description: 'Green maximum wavelength (nm)',
      factor: 1,
      unit: 'nm',
      writable: false
    }, {
      label: 'M',
      name: 'lambda-M',
      description: 'Blue maximum wavelength (nm)',
      factor: 1,
      unit: 'nm',
      writable: false
    }, {
      label: 'U',
      name: 'red test',
      description: 'Set intensity of red led for test (0 -> 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'V',
      name: 'green test',
      description: 'Set intensity of green led for test (0 -> 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'W',
      name: 'blue test',
      description: 'Set intensity of blue led for test (0 -> 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'X',
      name: 'white test',
      description: 'Set intensity of white led for test (0 -> 255)',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'Y'
    }, {
      label: 'Z'
    }]
  };

  var SimpleSpectro = {
    name: 'Simple spectrophotometer',
    kind: 'SimpleSpectro',
    numberParameters: 26,
    description: '',
    id: 'T',
    url: '',
    parameters: [{
      label: 'A',
      name: 'Transmission of sample (Red)',
      description: 'Frequency related to the energy of red led through sample',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'B',
      name: 'Transmission of sample (Green)',
      description: 'Frequency related to the energy of green led through sample',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'C',
      name: 'Transmission of sample (Blue)',
      description: 'Frequency related to the energy of blue led through sample',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'D',
      name: 'Emission of sample (Blue)',
      description: 'Frequency related to the energy of blue perpendicular led re-emitted by sample (fluorescence)',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'F',
      name: 'Transmission of blank (Red)',
      description: 'Frequency related to the energy of red led through blank',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'G',
      name: 'Transmission of blank (Green)',
      description: 'Frequency related to the energy of green led through blank',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'H',
      name: 'Transmission of blank (Blue)',
      description: 'Frequency related to the energy of blue led through blank',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'I',
      name: 'Emission of blank (Blue)',
      description: 'Frequency related to the energy of blue perpendicular led re-emitted by blank (fluorescence)',
      factor: 1,
      unit: 'Hz',
      writable: false
    }, {
      label: 'K',
      name: 'Delay before blank',
      description: 'Delay before the acquisition of the blank in seconds',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'L',
      name: 'Delay before sample',
      description: 'Delay before the acquisition of the sample in seconds',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'M',
      name: 'Delay between experiments',
      description: 'Delay between the acquisition of the experiments (kinetic) in seconds',
      factor: 1,
      unit: 's',
      writable: true
    }, {
      label: 'N',
      name: 'Nb experiments',
      description: 'Number of experiments for kinetic (max 240 / (number colors + 1))',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'O',
      name: 'Next exp. number',
      description: 'Number of the next experiment',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'P',
      name: 'Waiting time',
      description: 'Current waiting time before next experiment',
      factor: 1,
      unit: 's',
      writable: false
    }, {
      label: 'Q',
      name: 'Nb sampling',
      description: 'Number of acquisitions of 100ms that will be taken (default 10). This value could be reduced for fast kinetic',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'R',
      name: 'Invert rotary',
      description: ' Invert the rotary button direction',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'S',
      name: 'Battery voltage',
      description: 'Current battery voltage',
      factor: 100,
      unit: 'V',
      writable: true
    }, {
      label: 'T',
      name: 'Temperature',
      description: 'Current temperature',
      factor: 100,
      unit: '°C',
      writable: true
    }, {
      label: 'V',
      name: 'Active channels',
      description: 'Active leds and other. A number between 0 and 63. Each bit represents a function (Red, Green, Blue, UV, Voltage, Temperature). 5 would correspond to Red and Blue (binary combination).',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'W',
      name: 'Error',
      description: 'Error',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'X',
      name: 'Result channel',
      description: 'Value of the channel that will be displayed in the result',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'Y',
      name: 'Status',
      description: 'Status',
      factor: 1,
      unit: '',
      writable: true
    }, {
      label: 'Z',
      name: 'Current menu',
      description: 'Current menu',
      factor: 1,
      unit: '',
      writable: true
    }]
  };

  var Solar2015 = {
    name: 'Solar decathlon 2015',
    kind: 'Solar',
    numberParameters: 4,
    numberLogParameters: 4,
    id: '#',
    description: '',
    url: '',
    parameters: [{
      label: 'A',
      name: 'Temperature',
      description: '',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'B',
      name: 'Light',
      description: '',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'C',
      name: 'Pressure',
      description: '',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'D',
      name: 'Humidity',
      description: '',
      factor: 10,
      unit: '%',
      writable: false
    }]
  };

  var Beemos = {
    name: 'Bee Monistoring System',
    kind: 'Beemos',
    numberParameters: 32,
    numberLogParameters: 26,
    id: 'B',
    description: 'Bee Monistoring System data result',
    url: '',
    parameters: [{
      label: 'A',
      variable: 'externalTemperature',
      name: 'Ext temperature',
      description: 'External temperature',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'B',
      variable: 'externalHumidity',
      name: 'Ext humidity',
      description: 'External humidity',
      factor: 100,
      unit: '%',
      writable: false
    }, {
      label: 'C',
      variable: 'luminosity',
      name: 'Luminosity',
      description: 'Luminosity (Arbitrary unit)',
      factor: 10.24,
      unit: '',
      writable: false
    }, {
      label: 'D',
      variable: 'pressure',
      name: 'Pressure',
      description: 'Press',
      factor: 10,
      unit: 'mbar',
      writable: false
    }, {
      label: 'E',
      variable: 'internalTemperature',
      name: 'Int temperature',
      description: 'Internal temperature',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'F',
      variable: 'internalHumidity',
      name: 'Int humidity',
      description: 'Internal humidity',
      factor: 100,
      unit: '%',
      writable: false
    }, {
      label: 'G',
      variable: 'internalTemperatureA',
      name: 'Int temperature A',
      description: 'Internal temperature A',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'H',
      variable: 'internalTemperatureB',
      name: 'Int temperature B',
      description: 'Internal temperature B',
      factor: 100,
      unit: '°C',
      writable: false
    }, {
      label: 'I',
      variable: 'weight',
      name: 'Weight',
      description: 'Weight',
      factor: 100,
      unit: 'kg',
      writable: false
    }, {
      label: 'J',
      variable: 'battery',
      name: 'Battery',
      description: 'Battery voltage',
      factor: 1000,
      unit: 'V',
      writable: false
    }, {
      label: 'K',
      variable: 'gate1In',
      name: 'Gate 1 IN',
      description: 'Number of input on gate 1',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'L',
      variable: 'gate1Out',
      name: 'Gate 1 OUT',
      description: 'Number of output on gate 1',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'M',
      variable: 'gate2In',
      name: 'Gate 2 IN',
      description: 'Number of input on gate 2',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'N',
      variable: 'gate2Out',
      name: 'Gate 2 OUT',
      description: 'Number of output on gate 2',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'O',
      variable: 'gate3In',
      name: 'Gate 3 IN',
      description: 'Number of input on gate 3',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'P',
      variable: 'gate3Out',
      name: 'Gate 3 OUT',
      description: 'Number of output on gate 3',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'Q',
      variable: 'gate4In',
      name: 'Gate 4 IN',
      description: 'Number of input on gate 4',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'R',
      variable: 'gate4Out',
      name: 'Gate 4 OUT',
      description: 'Number of output on gate 4',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'S',
      variable: 'gate5In',
      name: 'Gate 5 IN',
      description: 'Number of input on gate 5',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'T',
      variable: 'gate5Out',
      name: 'Gate 5 OUT',
      description: 'Number of output on gate 5',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'U',
      variable: 'gate6In',
      name: 'Gate 6 IN',
      description: 'Number of input on gate 6',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'V',
      variable: 'gate6Out',
      name: 'Gate 6 OUT',
      description: 'Number of output on gate 6',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'W',
      variable: 'gate7In',
      name: 'Gate 7 IN',
      description: 'Number of input on gate 7',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'X',
      variable: 'gate7Out',
      name: 'Gate 7 OUT',
      description: 'Number of output on gate 7',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'Y',
      variable: 'gate8In',
      name: 'Gate 8 IN',
      description: 'Number of input on gate 8',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'Z',
      variable: 'gate8Out',
      name: 'Gate 8 OUT',
      description: 'Number of output on gate 8',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AA',
      variable: 'weightInternalUnit',
      name: 'Weight internal unit',
      description: 'Weight in internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AB',
      variable: 'weightOffset',
      name: 'Weight offset',
      description: 'Offset to convert weight from internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AC',
      variable: 'weightFactor',
      name: 'Weight factor',
      description: 'Factor to convert the weight from internal unit',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AD',
      variable: 'charging',
      name: 'Charging',
      description: 'Indication showing if the battery is charging',
      factor: 1,
      unit: '',
      writable: false
    }, {
      label: 'AE',
      variable: 'loggingInterval',
      name: 'Logging interval',
      description: 'Interval in seconds between logs',
      factor: 1,
      unit: 's',
      writable: true
    }]
  };

  var Computer = {
    name: 'Computer monitoring',
    kind: 'Computer',
    numberParameters: 16,
    numberLogParameters: 16,
    description: '',
    id: 'C',
    url: '',
    parameters: [{
      label: 'A',
      variable: 'cpuTemperature',
      name: 'CPU Temperature',
      description: '',
      factor: 1,
      unit: '°C',
      writable: false
    }, {
      label: 'B',
      variable: 'memFree',
      name: 'Free memory',
      description: 'Free memory in percent',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'C',
      variable: 'swapFree',
      name: 'Free swap',
      description: 'Free swap in percent',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'D',
      variable: 'fsRead',
      name: 'FS Read',
      description: 'File system read in kb',
      factor: 1,
      unit: 'kb',
      writable: false
    }, {
      label: 'E',
      variable: 'fsWrite',
      name: 'FS Write',
      description: 'File system read in kb',
      factor: 1,
      unit: 'kb',
      writable: false
    }, {
      label: 'F',
      variable: 'networkRead',
      name: 'Network Read',
      description: 'File system read in kb',
      factor: 1,
      unit: 'kb',
      writable: false
    }, {
      label: 'G',
      variable: 'networkWrite',
      name: 'Network Write',
      description: 'File system read in kb',
      factor: 1,
      unit: 'kb',
      writable: false
    }, {
      label: 'H',
      variable: 'load',
      name: 'Load',
      description: 'Total load',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'I',
      variable: 'userLoad',
      name: 'User load',
      description: 'Load from user',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'J',
      variable: 'systemLoad',
      name: 'System load',
      description: 'Load from system',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'K',
      variable: 'niceLoad',
      name: 'Nice load',
      description: 'Load for Nice',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'L',
      variable: 'idleLoad',
      name: 'Idle load',
      description: 'Idle percent of time',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'M',
      variable: 'irqLoad',
      name: 'IRQ load',
      description: 'Load due to IRQ',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'N',
      variable: 'fsMinimalUse',
      name: 'FS minimal use',
      description: 'Minimal percent spaced used in a filesystem',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'O',
      variable: 'fsMaximalUse',
      name: 'FS maximal use',
      description: 'Maximal percent spaced used in a filesystem',
      factor: 1,
      unit: '%',
      writable: false
    }, {
      label: 'P'
    }]
  };

  let devices = {
    OpenBio: OpenBio,
    OpenBio6: OpenBio6,
    OpenSpectro: OpenSpectro,
    SimpleSpectro: SimpleSpectro,
    Solar2015: Solar2015,
    Beemos: Beemos,
    Computer: Computer,
    fromDeviceID
  };
  /**
   * Return a device information from the deviceID
   * @param {string|number} id
   * @returns
   */

  function fromDeviceID(id) {
    if (typeof id === 'number') {
      id = String.fromCharCode(id / 256 >> 0) + String.fromCharCode(id % 256);
    }

    if (typeof id !== 'string') {
      throw Error('Device ID not a string or number');
    }

    if (id.length !== 2) {
      throw Error(`Device ID should be 2 character long and found: ${id.ldength}`);
    }

    const firstCharacter = id.substring(0, 1);

    for (let key in devices) {
      if (devices[key].id === firstCharacter) {
        return devices[key];
      }
    }

    return undefined;
  }

  var src = devices;

  return src;

})));
//# sourceMappingURL=legoino-device-information.js.map
